import unittest
from math_quiz import generate_random_int, choose_random_op, operator


class TestMathGame(unittest.TestCase):

    def test_generate_random_int(self):
        # Test if random numbers generated are within the specified range
        min_val = 1
        max_val = 10
        for _ in range(1000):  # Test a large number of random values
            rand_num = generate_random_int(min_val, max_val)
            self.assertTrue(min_val <= rand_num <= max_val)

    def choose_random_op(self):
        # Test if random operators generated are within the specified range
        operators = ['+', '-', '*']
        for _ in range(1000):
            rand_op = choose_random_op()
            self.assertTrue(rand_op in operators)
        

    def test_function_C(self):
            test_cases = [
                (5, 2, '+', '5 + 2', 7),
                (8, 3, '-', '8 - 3', 5),
                (4, 6, '*', '4 * 6', 24),
            ]

            for x in test_cases:
                # TODO
                # Unpack the test case tuple into variables
                # Call the function operator(num1, num2, operator) and compare
                problem, answer = operator(x[0], x[1], x[2])
                # the result with the expected result for each test case
                self.assertEqual(x[3], problem)
                self.assertEqual(x[4], answer)

if __name__ == "__main__":
    unittest.main()



import random


def generate_random_int(min: int, max: int):
    
    """
    min: int
    max: int
    
    Returns a random integer between min and max.
    """
    
    # return a random integer between min and max
    return random.randint(min, max)


def choose_random_op():
    
    """
    Returns a random operator from the list ['+', '-', '*']
    """

    # return a random operator from the list ['+', '-', '*']
    return random.choice(['+', '-', '*'])


def operator(number1: int, number2: int, operator: str):
    
    """_summary_
    number1 (int): number 1
    number2 (int): number 2
    operator:
        _type_: returns the result of the operation between n1 and n2
    """
    
    # return the result of the operation between n1 and n2
    result = f"{number1} {operator} {number2}"
    sol = 0
    if operator == '+': sol = number1 + number2
    elif operator == '-': sol = number1 - number2
    else: 
        sol = number1 * number2
    return result, sol

def math_quiz():
    
    """_summary_
    """
    
    # initialize score and pi
    score = 0
    num_problems = 3

    print("Welcome to the Math Quiz Game!")
    print("You will be presented with math problems, and you need to provide the correct answers.")

    for _ in range(num_problems):
        n1 = generate_random_int(1, 10); n2 = generate_random_int(1, 5); o = choose_random_op()

        PROBLEM, ANSWER = operator(n1, n2, o)
        print(f"\nQuestion: {PROBLEM}")
        
        try:
            useranswer = input("Your answer: ")
            useranswer = int(useranswer)
        except ValueError:
            print("Wrong input. Please enter an integer.")
            continue

        if useranswer == ANSWER:
            print("Correct! You earned a point.")
            score += 1
        else:
            print(f"Wrong answer. The correct answer is {ANSWER}.")

    print(f"\nGame over! Your score is: {score}/{num_problems}")

if __name__ == "__main__":
    math_quiz()



from setuptools import setup, find_packages

setup(
    name='math_quiz_Eid',
    version='1.0',
    packages=find_packages(),
    install_requires=[
        'Click',
        'pytest',
        'pytest-cov',
        'coverage',
        'flake8',
        'black',
        'sphinx',
        'sphinx_rtd_theme',
        'sphinx-click',
        'sphinxcontrib-napoleon',
        ],
)
